Package: cayleyR
Type: Package
Title: Cayley Graph Analysis for Permutation Puzzles
Version: 0.2.6
Authors@R: c(
    person(
      "Yuri", "Baramykov",
      email = "lbsbmsu@mail.ru",
      role = c("aut", "cre"),
      comment = c(ORCID = "0009-0000-7627-4217")
    )
  )
Description: Implements algorithms for analyzing Cayley graphs of
    permutation groups for the TopSpin puzzle. Provides methods for
    cycle detection, state space exploration and finding optimal operation
    sequences in permutation groups generated by shift and reverse
    operations. Also provides rule-defined landmark states for probing
    graphs too large to enumerate, and convex and non-convex hulls for
    measuring the solid such states span. The method Iterative Cycle
    Intersection (ICI) is described in Yuri Baramykov (2026)
    <doi:10.48550/arXiv.2607.13219>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: Rcpp
LinkingTo: Rcpp
Suggests: testthat (>= 3.0.0), ggmlR, data.table, knitr, rmarkdown
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://github.com/Zabis13/cayleyR,
        https://arxiv.org/abs/2607.13219
BugReports: https://github.com/Zabis13/cayleyR/issues
NeedsCompilation: yes
Packaged: 2026-07-29 18:12:02 UTC; yuri
Author: Yuri Baramykov [aut, cre] (ORCID:
    <https://orcid.org/0009-0000-7627-4217>)
Maintainer: Yuri Baramykov <lbsbmsu@mail.ru>
Repository: CRAN
Date/Publication: 2026-07-29 21:50:07 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-07-30 00:27:36 UTC; unix
Archs: cayleyR.so.dSYM
