Package: cayleyR
Type: Package
Title: Cayley Graph Analysis for Permutation Puzzles
Version: 0.2.1
Authors@R: c(
    person(
      "Yuri", "Baramykov",
      email = "lbsbmsu@mail.ru",
      role = c("aut", "cre")
    )
  )
Description: Implements algorithms for analyzing Cayley graphs of permutation groups,
    with a focus on the TopSpin puzzle and similar permutation-based combinatorial
    puzzles. Provides methods for cycle detection, state space exploration,
    bidirectional BFS pathfinding, and finding optimal operation sequences
    in permutation groups generated by shift and reverse operations.
    Includes C++ implementations of core operations via 'Rcpp' for performance.
    Optional GPU acceleration via 'ggmlR' Vulkan backend for batch distance
    calculations and parallel state transformations.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: Rcpp
LinkingTo: Rcpp
Suggests: testthat (>= 3.0.0), ggmlR, data.table
Config/testthat/edition: 3
URL: https://github.com/Zabis13/cayleyR
BugReports: https://github.com/Zabis13/cayleyR/issues
NeedsCompilation: yes
Packaged: 2026-03-01 12:20:37 UTC; yuri
Author: Yuri Baramykov [aut, cre]
Maintainer: Yuri Baramykov <lbsbmsu@mail.ru>
Repository: CRAN
Date/Publication: 2026-03-01 13:30:17 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 14:02:24 UTC; unix
Archs: cayleyR.so.dSYM
