# Generated by roxygen2: do not edit by hand

export(analyze_top_combinations)
export(apply_operations)
export(apply_operations_batch_gpu)
export(bidirectional_bfs)
export(breakpoint_distance)
export(build_permutation_matrix)
export(calculate_angular_distance_z)
export(calculate_differences)
export(calculate_midpoint_z)
export(cayley_bfs_full)
export(cayley_distance)
export(cayley_distance_methods)
export(cayley_gpu_available)
export(cayley_gpu_free)
export(cayley_gpu_init)
export(cayley_gpu_status)
export(cayley_graph_diameter)
export(check_duplicates)
export(compose_permutation_matrix)
export(convert_LRX_to_celestial)
export(convert_digits)
export(convex_hull_3d)
export(create_state_store)
export(cycle_shortcut)
export(enclosing_hull_3d)
export(find_best_match_human)
export(find_best_random_combinations)
export(find_closest_to_coords)
export(find_combination_in_states)
export(find_path_bfs)
export(find_path_iterative)
export(generate_state)
export(generate_unique_states_df)
export(get_reachable_states)
export(get_reachable_states_light)
export(human_algorithm)
export(human_algorithm_to)
export(human_phase1_navigate)
export(human_phase1_rank)
export(invert_path)
export(landmark_states)
export(manhattan_distance)
export(manhattan_distance_matrix_gpu)
export(openmp_threads)
export(reconstruct_bfs_path)
export(reverse_prefix)
export(reverse_prefix_simple)
export(run_length)
export(save_bridge_states)
export(select_unique)
export(shift_left)
export(shift_left_simple)
export(shift_right)
export(shift_right_simple)
export(short_path_bfs)
export(short_position)
export(sparse_bfs)
export(state_store_indices_for_cycle)
export(state_store_perm_length)
export(state_store_size)
export(state_store_unique_count)
export(store_add_from_df)
export(store_analyze_combos)
export(store_analyze_combos_gpu)
export(store_clear)
export(store_clear_opd)
export(store_collect_ops)
export(store_combos_for_state)
export(store_filter_middle)
export(store_find_best_match)
export(store_find_intersections)
export(store_get_meta)
export(store_get_state)
export(store_lookup)
export(store_reconstruct_path)
export(store_set_opd)
export(store_to_dataframe)
export(validate_and_simplify_path)
importFrom(Rcpp,sourceCpp)
importFrom(utils,flush.console)
importFrom(utils,write.table)
useDynLib(cayleyR, .registration = TRUE)
